@@ -16,6 +16,9 @@ pref("toolbar.customization.usesheet", true); // true for Mac
 pref("toolbar.customization.usesheet", false); // false otherwise
 #endif
 
+/* main theme */
+pref("bluegriffon.wysiwyg.theme", "black");
+
 /* debugging prefs */
 pref("browser.dom.window.dump.enabled", false);
 pref("javascript.options.showInConsole", false);
@@ -146,6 +149,8 @@ pref("bluegriffon.source.wrap.maxColumn", 80);
 pref("bluegriffon.source.wrap.exclude-languages", true);
 pref("bluegriffon.source.wrap.language-exclusions", "");
 
+pref("bluegriffon.toolbar.enabled", true);
+pref("bluegriffon.toolbar.icons", "medium");
 pref("bluegriffon.tabs.position", "center");
 
 pref("bluegriffon.osx.dock-integration", true);
@@ -215,3 +220,8 @@ pref("general.useragent.locale", "en-US");
 pref("intl.locale.matchOS", true);
 
 pref("app.support.baseURL", "http://bluegriffon.org/");
+
+pref("bluegriffon.responsive.default", "min"); // min, max, minmax
+
+// Blocklist preferences
+pref("extensions.blocklist.enabled", false);
